pub mod tim;

use std::path::PathBuf;
use slint::Image;
use tim::{Encoding, TIMInfo};
use tool_helper::Error;

pub struct Logic {
    unadded_tim: Option<TIMInfo>,
}

impl Logic {
    pub fn new() -> Logic {
        Logic{unadded_tim: None}
    }

    pub fn set_unadded_tim(&mut self, path: &PathBuf) -> Result<(Image, Option<Image>), Error> {
        let tim_info = TIMInfo::from_image(path)?;
        let image    = tim_info.get_slint_images(Encoding::FullColor);

        self.unadded_tim = Some(tim_info);
        Ok(image)
    }

    pub fn add_unadded_tim_as(&mut self, _name: &String, encoding: Encoding) -> Result<(Image, Option<Image>), Error> {
        if let Some(unadded_tim) = &self.unadded_tim {
            let (image, palette) = unadded_tim.get_slint_images(encoding);

            self.unadded_tim = None;
            Ok((image, palette))
        }

        else {
            Err(Error::from_str("No data found for loaded image"))
        }
    }

    pub fn change_unadded_tim_palette_size(&mut self, width: u32, height: u32) -> Result<Option<Image>, Error> {
        if let Some(unadded_tim) = &mut self.unadded_tim {
            unadded_tim.change_palette_size(width, height)
        }

        else {
            Ok(None)
        }
    }
}